@@ -1,12 +1,10 @@
-import codecs
 import hashlib
 import json
 import logging
 import os
-from typing import Dict, Tuple
+from typing import Dict, Tuple, Optional
 
 import boto3
-from eth_keys import keys
 
 from hmt_escrow import crypto
 
@@ -43,6 +41,15 @@ def _connect_s3():
         raise e
 
 
+def download_from_storage(key: str) -> bytes:
+    """ Downloads data from storage if exists. """
+    LOG.debug("Downloading s3 key: {}".format(key))
+
+    BOTO3_CLIENT = _connect_s3()
+    response = BOTO3_CLIENT.get_object(Bucket=ESCROW_BUCKETNAME, Key=key)
+    return response["Body"].read()
+
+
 def download(key: str, private_key: bytes) -> Dict:
     """Download a key, decrypt it, and output it as a binary string.
 
@@ -58,22 +65,25 @@ def download(key: str, private_key: bytes) -> Dict:
 
     """
     try:
-        LOG.debug("Downloading s3 key: {}".format(key))
-        BOTO3_CLIENT = _connect_s3()
-        response = BOTO3_CLIENT.get_object(Bucket=ESCROW_BUCKETNAME, Key=key)
-        ciphertext = response["Body"].read()
-        msg = _decrypt(private_key, ciphertext)
+        content = download_from_storage(key)
+        artifact = (
+            crypto.decrypt(private_key, content)
+            if crypto.is_encrypted(content) is True
+            else content.decode()
+        )
+
     except Exception as e:
         LOG.warning(
-            "Reading the key {!r} with private key {!r} with S3 failed because of: {!r}".format(
-                key, private_key, e
-            )
+            "Reading the key {!r} with private key {!r} with S3 failed"
+            " because of: {!r}".format(key, private_key, e)
         )
         raise e
-    return json.loads(msg)
+    return json.loads(artifact)
 
 
-def upload(msg: Dict, public_key: bytes) -> Tuple[str, str]:
+def upload(
+    msg: Dict, public_key: bytes, encrypt_data: Optional[bool] = False
+) -> Tuple[str, str]:
     """Upload and encrypt a string for later retrieval.
     This can be manifest files, results, or anything that's been already
     encrypted.
@@ -81,6 +91,7 @@ def upload(msg: Dict, public_key: bytes) -> Tuple[str, str]:
     Args:
         msg (Dict): The message to upload and encrypt.
         public_key (bytes): The public_key to encrypt the file for.
+        encrypt_data (bool): Whether data must be encrypted before uploading.
 
     Returns:
         Tuple[str, str]: returns the contents of the filename which was previously uploaded.
@@ -90,48 +101,21 @@ def upload(msg: Dict, public_key: bytes) -> Tuple[str, str]:
 
     """
     try:
-        manifest_ = json.dumps(msg, sort_keys=True)
+        artifact = json.dumps(msg, sort_keys=True)
     except Exception as e:
         LOG.error("Can't extract the json from the dict")
         raise e
 
-    hash_ = hashlib.sha1(manifest_.encode("utf-8")).hexdigest()
+    content = artifact.encode("utf-8")
+
+    hash_ = hashlib.sha1(content).hexdigest()
+    key = f"s3{hash_}"
+
+    if encrypt_data is True:
+        content = crypto.encrypt(public_key, artifact)
 
     BOTO3_CLIENT = _connect_s3()
-    encrypted_msg = _encrypt(public_key, manifest_)
-    key = f"s3{hash_}"
-    BOTO3_CLIENT.put_object(Bucket=ESCROW_BUCKETNAME, Key=key, Body=encrypted_msg)
+    BOTO3_CLIENT.put_object(Bucket=ESCROW_BUCKETNAME, Key=key, Body=content)
+
     LOG.debug(f"Uploaded to S3, key: {key}")
     return hash_, key
-
-
-def _decrypt(private_key: bytes, msg: bytes) -> str:
-    """Use ECIES to decrypt a message with a given private key and an optional MAC.
-
-    Args:
-        private_key (bytes): The private_key to decrypt the message with.
-        msg (bytes): The message to be decrypted.
-
-    Returns:
-        str: returns the plaintext equivalent to the originally encrypted one.
-
-    """
-    priv_key = keys.PrivateKey(codecs.decode(private_key, "hex"))
-    e = crypto.decrypt(msg, priv_key, shared_mac_data=SHARED_MAC_DATA)
-    return e.decode("utf-8")
-
-
-def _encrypt(public_key: bytes, msg: str) -> bytes:
-    """Use ECIES to encrypt a message with a given public key and optional MAC.
-
-    Args:
-        public_key (bytes): The public_key to encrypt the message with.
-        msg (str): The message to be encrypted.
-
-    Returns:
-        bytes: returns the cryptotext encrypted with the public key.
-
-    """
-    pub_key = keys.PublicKey(codecs.decode(public_key, "hex"))
-    msg_bytes = msg.encode("utf-8")
-    return crypto.encrypt(msg_bytes, pub_key, shared_mac_data=SHARED_MAC_DATA)
